/*
 * Stairs lighting
 * Copyright 2017 (c) Mark van Renswoude
 *
 * https://git.x2software.net/pub/Stairs
 *
 * This code was ported over from Domoticz' SunRiseSet.cpp
 * https://github.com/domoticz/domoticz/
*/
#ifndef __praisethesun
#define __praisethesun

double daylen( int year, int month, int day, double lon, double lat, double altit, int upper_limb );

int sunriset( int year, int month, int day, double lon, double lat,
              double altit, int upper_limb, double *trise, double *tset );


/* This macro computes the length of the day, from sunrise to sunset. */
/* Sunrise/set is considered to occur when the Sun's upper limb is  */
/* 35 arc minutes below the horizon (this accounts for the refraction */
/* of the Earth's atmosphere).                    */
#define day_length(year,month,day,lon,lat)  \
    daylen(year, month, day, lon, lat, -35.0/60.0, 1)

/* This macro computes the length of the day, including civil twilight. */
/* Civil twilight starts/ends when the Sun's center is 6 degrees below  */
/* the horizon.                            */
#define day_civil_twilight_length(year,month,day,lon,lat)  \
    daylen(year, month, day, lon, lat, -6.0, 0)

/* This macro computes the length of the day, incl. nautical twilight.  */
/* Nautical twilight starts/ends when the Sun's center is 12 degrees  */
/* below the horizon.                          */
#define day_nautical_twilight_length(year,month,day,lon,lat)  \
    daylen(year, month, day, lon, lat, -12.0, 0)

/* This macro computes the length of the day, incl. astronomical twilight. */
/* Astronomical twilight starts/ends when the Sun's center is 18 degrees   */
/* below the horizon.                           */
#define day_astronomical_twilight_length(year,month,day,lon,lat)  \
    daylen(year, month, day, lon, lat, -18.0, 0)

/* This macro computes times for sunrise/sunset.            */
/* Sunrise/set is considered to occur when the Sun's upper limb is  */
/* 35 arc minutes below the horizon (this accounts for the refraction */
/* of the Earth's atmosphere).                    */
#define sun_rise_set(year,month,day,lon,lat,rise,set)  \
    sunriset( year, month, day, lon, lat, -35.0/60.0, 1, rise, set )

/* This macro computes the start and end times of civil twilight.    */
/* Civil twilight starts/ends when the Sun's center is 6 degrees below  */
/* the horizon.                            */
#define civil_twilight(year,month,day,lon,lat,start,end)  \
    sunriset( year, month, day, lon, lat, -6.0, 0, start, end )

/* This macro computes the start and end times of nautical twilight.  */
/* Nautical twilight starts/ends when the Sun's center is 12 degrees  */
/* below the horizon.                          */
#define nautical_twilight(year,month,day,lon,lat,start,end)  \
    sunriset( year, month, day, lon, lat, -12.0, 0, start, end )

/* This macro computes the start and end times of astronomical twilight.   */
/* Astronomical twilight starts/ends when the Sun's center is 18 degrees   */
/* below the horizon.                           */
#define astronomical_twilight(year,month,day,lon,lat,start,end)  \
    sunriset( year, month, day, lon, lat, -18.0, 0, start, end )

#endif