/*
 * Stairs
 * Copyright 2017 (c) Mark van Renswoude
 *
 * https://git.x2software.net/pub/Stairs
*/
#include "./steps.h"
#include <ArduinoJson.h>
#include "../debug.h"


StepsSettings::StepsSettings()
{
  for (uint8_t i = 0; i < MaxStepCount; i++)
    mCurveShift[i] = 0;
}


void StepsSettings::toJson(Print &print)
{
  DynamicJsonBuffer jsonBuffer(JSON_ARRAY_SIZE(16) + JSON_OBJECT_SIZE(3));

  JsonObject& root = jsonBuffer.createObject();
  root["count"] = count();
  root["useCurve"] = useCurve();

  JsonArray& jsonCurveShift = root.createNestedArray("curveShift");
  for (uint8_t step = 0; step < MaxStepCount; step++)
    jsonCurveShift.add(curveShift(step));

  root.printTo(print);
}


bool StepsSettings::fromJson(char* data, bool* changed)
{
  if (changed != nullptr)
    *changed = false;

  DynamicJsonBuffer jsonBuffer(JSON_ARRAY_SIZE(16) + JSON_OBJECT_SIZE(3) + 80);
  JsonObject& root = jsonBuffer.parseObject(data);

  if (!root.success())
    return false;

  uint8_t jsonCount = root["count"];
  bool jsonUseCurve = root["useCurve"];

  if (jsonCount != count() ||
      jsonUseCurve != useCurve())
  {
    count(jsonCount);
    useCurve(jsonUseCurve);

    if (changed != nullptr)
      *changed = true;
  }


  JsonArray& jsonCurveShift = root["curveShift"];
  uint8_t stepCount = jsonCurveShift.size();
  if (stepCount >= MaxStepCount)
    stepCount = MaxStepCount - 1;

  for (uint8_t step = 0; step < stepCount; step++)
  {
    uint16_t value = jsonCurveShift[step];

    if (value != curveShift(step))
    {
      curveShift(step, value);
      if (changed != nullptr)
        *changed = true;
    }
  }

  return true;
}