/*
 * Stairs
 * Copyright 2017 (c) Mark van Renswoude
 *
 * https://git.x2software.net/pub/Stairs
*/
#ifndef __settingstriggersmotion
#define __settingstriggersmotion

#include <Arduino.h>
#include "../../config.h"
#include "../abstractjson.h"


enum MotionDirection
{
  Nondirectional = 1,
  TopDown = 2,
  BottomUp = 3
};


struct MotionTrigger
{
  uint8_t pin;
  uint8_t brightness;
  MotionDirection direction;
  bool enabled;
};


class MotionTriggerSettings : public AbstractJsonSettings
{
  private:
    bool mEnabled = false;
    bool mEnabledDuringTimeTrigger = false;
    uint16_t mTransitionTime = 0;
    uint32_t mDelay = 0;
    uint8_t mTriggerCount = 0;
    MotionTrigger* mTriggers = nullptr;

  protected:
    virtual const char* getFilename() { return MotionTriggerSettingsFile; };
    virtual const char* getDebugPrefix() { return "MotionTriggerSettings"; };

  public:
    void toJson(Print &print);
    bool fromJson(char* data, bool* changed);


    bool enabled() { return mEnabled; }
    void enabled(bool value) { mEnabled = value; }

    bool enabledDuringTimeTrigger() { return mEnabledDuringTimeTrigger; }
    void enabledDuringTimeTrigger(bool value) { mEnabledDuringTimeTrigger = value; }

    uint16_t transitionTime() { return mTransitionTime; }
    void transitionTime(uint16_t value) { mTransitionTime = value; }

    uint32_t delay() { return mDelay; }
    void delay(uint32_t value) { mDelay = value; }

    uint8_t triggerCount() { return mTriggerCount; }
    MotionTrigger* trigger(uint8_t index) { return &mTriggers[index]; }
};

#endif